NodeState

Struct NodeState 

pub struct NodeState {
    pub head: f64,
    pub demand_flow: f64,
    pub emitter_flow: f64,
    pub leakage_flow: f64,
    pub net_flow: f64,
    pub level: f64,
    pub volume: f64,
    pub quality: f64,
}
Per-step hydraulic and quality state for a single node (2.4, per-step fields).

Not all fields are meaningful for every node type:

  • head, quality: all node types.
  • demand_flow, emitter_flow, leakage_flow: junctions only.
  • net_flow: reservoirs and tanks.
  • level, volume: tanks only.

Fields

head: f64

Hydraulic head (m).

demand_flow: f64

Actual delivered demand flow (m³/s).

emitter_flow: f64

Emitter outflow (m³/s).

leakage_flow: f64

Leakage outflow from FAVAD model (m³/s).

net_flow: f64

Net inflow to reservoir or tank (m³/s; positive = filling).

level: f64

Current water level above tank bottom (m); tanks only.

volume: f64

Current tank volume (m³); tanks only.

quality: f64

Water quality concentration (mg/L, h, or % depending on mode).